/**
 * @file
 * vuo.leap.get.hand node implementation.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include "VuoLeapHand.h"
#include "VuoLeapPointable.h"
#include "VuoList_VuoLeapPointable.h"

VuoModuleMetadata({
					  "title" : "Get Hand Values",
					  "keywords" : [ "controller", "motion", "hand", "palm" ],
					  "version" : "2.0.0",
					  "node": {
						  "exampleCompositions" : [ "DisplayLeapHand.vuo", "ShowHandStatus.vuo", "HighlightExtendedFingers.vuo", "TwirlImageWithLeap.vuo" ]
					  }
				  });

void nodeEvent
(
		VuoInputData(VuoLeapHand) hand,
		VuoOutputData(VuoInteger, {"name":"ID"}) id,
		VuoOutputData(VuoTransform) transform,
		VuoOutputData(VuoTransform) palmTransform,
		VuoOutputData(VuoTransform) stabilizedPalmTransform,
		VuoOutputData(VuoPoint3d) palmVelocity,
		VuoOutputData(VuoPoint3d) wristPosition,
		VuoOutputData(VuoReal) sphereRadius,
		VuoOutputData(VuoPoint3d) sphereCenter,
		VuoOutputData(VuoReal) pinchAmount,
		VuoOutputData(VuoReal) grabAmount,
		VuoOutputData(VuoBoolean) isLeftHand,
		VuoOutputData(VuoReal) timeVisible,
		VuoOutputData(VuoReal) confidence,
		VuoOutputData(VuoList_VuoLeapPointable) fingers
)
{
	*id = hand.id;

	VuoPoint4d handQuaternion = VuoTransform_quaternionFromVectors(VuoPoint3d_make(0,0,-1), hand.direction);
	VuoPoint4d palmQuaternion = VuoTransform_quaternionFromVectors(VuoPoint3d_make(0,0,-1), hand.palmNormal);
	VuoPoint3d scale = VuoPoint3d_make(hand.palmWidth, hand.palmWidth, hand.palmWidth);
	*transform               = VuoTransform_makeQuaternion(hand.palmPosition,           handQuaternion, scale);
	*palmTransform           = VuoTransform_makeQuaternion(hand.palmPosition,           palmQuaternion, scale);
	*stabilizedPalmTransform = VuoTransform_makeQuaternion(hand.stabilizedPalmPosition, palmQuaternion, scale);

	*palmVelocity = hand.palmVelocity;
	*wristPosition = hand.wristPosition;
	*sphereRadius = hand.sphereRadius;
	*sphereCenter = hand.sphereCenter;
	*pinchAmount = hand.pinchAmount;
	*grabAmount = hand.grabAmount;
	*isLeftHand = hand.isLeftHand;
	*timeVisible = hand.timeVisible;
	*confidence = hand.confidence;

	*fingers = hand.fingers ? hand.fingers : VuoListCreate_VuoLeapPointable();
}
